$_ = [
  {
    'WebDyne::Chain' => '1.28',
    'Tie::IxHash' => '1.21',
    'Bundle::WebMod::Base' => '1.58',
    'Storable' => '2.15',
    'WebDyne::State' => '1.3',
    'HTML::TreeBuilder' => '3.13',
    'CGI' => '3.10',
    'Bundle::WebDyne::Dist' => '1.26',
    'WebMod::Err' => '1.25',
    'Digest::MD5' => '2.33',
    'WebMod::Base' => '1.8',
    'WebDyne::Template' => '1.5',
    'WebMod::Proto' => '1.9',
    'URI' => '1.35',
    'Net::FTP' => '2.75',
    'WebDyne' => '1.93',
    'HTML::HeadParser' => '2.22',
    'WebDyne::Err' => '1.23',
    'Digest::base' => '1.00',
    'Time::HiRes' => '1.87',
    'WebDyne::Session' => '1.19',
    'WebDyne::Install' => '1.50',
    'WebMod::Debug' => '1.28',
    'BerkeleyDB' => '0.27',
    'Bundle::LWP' => '1.11',
    'MIME::Base64' => '3.05',
    'HTML::Parser' => '3.51',
    'HTML::Tagset' => '3.04',
    'WebMod::Log' => '1.16',
    'WebMod::Constant' => '1.15',
    'LWP' => '5.803',
    'Text::Template' => '1.44'
  },
  {
    'S/SB/SBURKE/HTML-Tagset-3.04.tar.gz' => [
      'HTML::Tagset'
    ],
    'A/AS/ASPEER/WebDyne-Session-1.19.tar.gz' => [
      'WebDyne::Session'
    ],
    'G/GA/GAAS/Digest-MD5-2.33.tar.gz' => [
      'Digest::MD5'
    ],
    'G/GA/GAAS/Digest-1.12.tar.gz' => [
      'Digest::base'
    ],
    'A/AM/AMS/Storable-2.15.tar.gz' => [
      'Storable'
    ],
    'A/AS/ASPEER/WebDyne-Err-1.23.tar.gz' => [
      'WebDyne::Err'
    ],
    'A/AS/ASPEER/WebDyne-State-1.3.tar.gz' => [
      'WebDyne::State'
    ],
    'G/GA/GAAS/HTML-Parser-3.51.tar.gz' => [
      'HTML::HeadParser',
      'HTML::Parser'
    ],
    'A/AS/ASPEER/WebMod-Constant-1.15.tar.gz' => [
      'WebMod::Constant'
    ],
    'A/AS/ASPEER/WebDyne-1.93.tar.gz' => [
      'WebDyne'
    ],
    'A/AS/ASPEER/WebDyne-Chain-1.28.tar.gz' => [
      'WebDyne::Chain'
    ],
    'M/MJ/MJD/Text-Template-1.44.tar.gz' => [
      'Text::Template'
    ],
    'A/AS/ASPEER/Bundle-WebMod-Base-1.58.tar.gz' => [
      'Bundle::WebMod::Base'
    ],
    'G/GA/GAAS/URI-1.35.tar.gz' => [
      'URI'
    ],
    'A/AS/ASPEER/WebMod-Err-1.25.tar.gz' => [
      'WebMod::Err'
    ],
    'A/AS/ASPEER/Bundle-WebDyne-Dist-1.26.tar.gz' => [
      'Bundle::WebDyne::Dist'
    ],
    'A/AS/ASPEER/WebDyne-Template-1.5.tar.gz' => [
      'WebDyne::Template'
    ],
    'P/PM/PMQS/BerkeleyDB-0.27.tar.gz' => [
      'BerkeleyDB'
    ],
    'A/AS/ASPEER/WebDyne-Install-1.50.tar.gz' => [
      'WebDyne::Install'
    ],
    'G/GA/GAAS/MIME-Base64-3.05.tar.gz' => [
      'MIME::Base64'
    ],
    'A/AS/ASPEER/WebMod-Log-1.16.tar.gz' => [
      'WebMod::Log'
    ],
    'A/AS/ASPEER/WebMod-Base-1.8.tar.gz' => [
      'WebMod::Base'
    ],
    'J/JH/JHI/Time-HiRes-1.87.tar.gz' => [
      'Time::HiRes'
    ],
    'G/GS/GSAR/Tie-IxHash-1.21.tar.gz' => [
      'Tie::IxHash'
    ],
    'A/AS/ASPEER/WebMod-Debug-1.28.tar.gz' => [
      'WebMod::Debug'
    ],
    'S/SB/SBURKE/HTML-Tree-3.18.tar.gz' => [
      'HTML::TreeBuilder'
    ],
    'L/LD/LDS/CGI.pm-3.10.tar.gz' => [
      'CGI'
    ],
    'G/GB/GBARR/libnet-1.19.tar.gz' => [
      'Net::FTP'
    ],
    'G/GA/GAAS/libwww-perl-5.803.tar.gz' => [
      'Bundle::LWP',
      'LWP'
    ],
    'A/AS/ASPEER/WebMod-Proto-1.9.tar.gz' => [
      'WebMod::Proto'
    ]
  },
  [
    'Digest::base',
    'Net::FTP',
    'URI',
    'MIME::Base64',
    'Digest::MD5',
    'HTML::Tagset',
    'HTML::Parser',
    'HTML::HeadParser',
    'LWP',
    'Bundle::LWP',
    'WebMod::Base',
    'WebMod::Err',
    'WebMod::Debug',
    'WebMod::Log',
    'WebMod::Constant',
    'WebMod::Proto',
    'Bundle::WebMod::Base',
    'BerkeleyDB',
    'HTML::TreeBuilder',
    'Text::Template',
    'Time::HiRes',
    'Tie::IxHash',
    'Storable',
    'CGI',
    'WebDyne',
    'WebDyne::Chain',
    'WebDyne::Err',
    'WebDyne::Template',
    'WebDyne::Session',
    'WebDyne::State',
    'WebDyne::Install',
    'Bundle::WebDyne::Dist'
  ]
];
